@@ -4,7 +4,7 @@ use 5.012;
 use Encode();
 use Time::HiRes();
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.1.1';
 
 =head1 NAME
 
@@ -358,17 +358,19 @@ Calculates 32-bit hash value for $string. Currently uses jenkins_one_at_a_time_h
 
 =head1 C FUNCTIONS
 
-=head4 HV* xs::lib::hash_merge (HV* dest, HV* source, IV flags)
+Functions marked with C<[pTHX]> must receive C<aTHX_> as a first arg.
 
-=head4 SV* xs::lib::merge (SV* dest, SV* source, IV flags)
+=head4 HV* xs::lib::hash_merge (HV* dest, HV* source, IV flags) [pTHX]
 
-=head4 SV* xs::lib::clone (SV* source, bool cross_references)
+=head4 SV* xs::lib::merge (SV* dest, SV* source, IV flags) [pTHX]
 
-=head4 bool xs::lib::hv_compare (HV*, HV*)
+=head4 SV* xs::lib::clone (SV* source, bool cross_references) [pTHX]
 
-=head4 bool xs::lib::av_compare (AV*, AV*)
+=head4 bool xs::lib::hv_compare (HV*, HV*) [pTHX]
 
-=head4 bool xs::lib::sv_compare (SV*, SV*)
+=head4 bool xs::lib::av_compare (AV*, AV*) [pTHX]
+
+=head4 bool xs::lib::sv_compare (SV*, SV*) [pTHX]
 
 =head4 uint64_t panda::lib::string_hash (const char* str, size_t len)
 
@@ -385,7 +387,7 @@ All functions above behaves like its perl equivalents. See PERL FUNCTIONS docs.
 Performs XOR crypt. If 'dest' is null, mallocs and returns new buffer. Buffer must be freed by user manually via 'free'. If 'dest'
 is not null, places result into this buffer. It must have enough space to hold the result.
 
-=head4 panda::string xs::lib::sv2string (SV* svstr, panda::string::ref_t ref = panda::string::COPY)
+=head4 panda::string xs::lib::sv2string (SV* svstr, panda::string::ref_t ref = panda::string::COPY) [pTHX]
 
 Creates panda::string from SV string. If 'ref' is COPY then content of SV is copied to string. If 'ref' is REF, then returned
 string is a copy-on-write string holding SV's buffer. In this case you must NOT change or delete your SV until you're done with string.
